@@ -56,11 +56,13 @@ def get_departments(organization_id: int, department_name: str = None) -> dict:
                     obj = Department.objects.filter(pk=i).only("name").first()
                     dic["id"] = obj.id
                     dic["name"] = obj.name
+                    dic["show_order"] = obj.show_order
                     lst.append(dic)
             # 最后把部门本身的内容也append到返回列表中
             lst.append({
                 "id": instance.id,
-                "name": instance.name
+                "name": instance.name,
+                "show_order": instance.show_order
             })
             items.append(lst)
 
@@ -216,7 +218,19 @@ def delete_department(organization_id: int, pk: int):
     :param pk:
     :return:
     """
-    Department.objects.filter(organization_id=organization_id, pk=pk).delete()
+    instance = Department.objects.filter(organization_id=organization_id, pk=pk).first()
+    if instance.path:
+        path = instance.path
+    else:
+        raise ValueError("一级部门不允许删除")
+    path.append(instance.id)
+    dic = {f"path__0_{len(path)}": path}
+    departments = list(Department.objects.filter(**dic).values_list("id", flat=True))
+    print(departments)
+    departments.append(instance.id)
+    if DepartmentUserMap.objects.filter(department_id__in=departments).exists():
+        raise ValueError("当前部门或子部门下还有用户, 无法删除!")
+    Department.objects.filter(id__in=departments).delete()
     return Resp(data="删除成功")
 
 
