@@ -36,15 +36,15 @@ if __name__ == '__main__':
 
     obj = DepartmentViewSet(1)
     # print(obj.list("sub", 2))
-    # print(obj.list("all"))
+    print(obj.list("all"))
     # print(obj.list("all", department_name="o"))
     # print(obj.create({"name": "前端o1", "parent_id": 2, "charger_id": 11}))
     # print(obj.retrieve(3))
     # print(obj.update(2, {"name": "前端2", "parent_id": 4, "charger_id": None}))
-    # print(obj.delete(14))
+    # print(obj.delete(2))
     # print(obj.move_show_order(9, "up"))
     # print(obj.create_department_user(5, [1, 2, 3]))
-    print(obj.department_user_list(5,))
+    # print(obj.department_user_list(5,))
     # print(obj.delete_department_user(5, [11]))
 
 
